@@ -3,7 +3,6 @@ FASTGenomics Base Library
 """
 
 __copyright__ = "Copyright, Comma Soft AG"
-__version__ = "0.2.0"
 __maintainer__ = "Ralf Karle"
 __email__ = "ralf.karle@comma-soft.com"
 
@@ -22,6 +21,7 @@ from random import choice
 from subprocess import CompletedProcess
 from typing import List, Union
 from urllib.parse import urlparse
+from . import __version__
 
 import requests
 from requests.adapters import Retry
@@ -945,7 +945,7 @@ class FASTGenomicsLargeFileStorageClient(FASTGenomicsClient):
 
         return
 
-    def __create_dataset_and_attach_lfs(self, sai: LargeFileStorageAccessInformation, title: str) -> str:
+    def __create_dataset_and_attach_lfs(self, sai: LargeFileStorageAccessInformation, title: str, dataset_type: str = "cs-singlecell") -> str:
         """ create a dataset and attach the lfs """
         bearer_token = self._get_bearer_token()
 
@@ -955,6 +955,7 @@ class FASTGenomicsLargeFileStorageClient(FASTGenomicsClient):
 
         request_data = {
             "title": title,
+            "typeId": dataset_type,
             "files": []
         }
 
@@ -1324,7 +1325,8 @@ class FASTGenomicsDatasetClient(FASTGenomicsClient):
         bytes_transferred = 0
         chunkId = 1
 
-        show_bar = show_progress_bar is not False and (show_progress_bar or log_level <= logging.INFO)
+        show_bar = show_progress_bar is not False and (
+            show_progress_bar or log_level <= logging.INFO)
 
         progress_bar = None
         if show_bar:
@@ -1381,12 +1383,13 @@ class FASTGenomicsDatasetClient(FASTGenomicsClient):
             url, headers=headers)
         self._handle_response(response)
 
-    def create_dataset(self, title: str) -> requests.Response:
+    def create_dataset(self, title: str, dataset_type: str) -> requests.Response:
         logging.info(f"creating dataset {title}")
         bearer_token = self._get_bearer_token()
-        url = self._get_url(f"webclient/api/datasets")
+        url = self._get_url("webclient/api/datasets")
         request_data = {
             "title": title,
+            "typeId": dataset_type,
             "files": []
         }
         request_json = json.dumps(request_data)
